import { HttpUrlEncodingCodec, HttpClient, HttpHeaders, HttpParams } from '@angular/common/http';
import { InjectionToken, Inject, Injectable, Optional, NgModule, SkipSelf } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * CustomHttpUrlEncodingCodec
 * Fix plus sign (+) not encoding, so sent as blank space
 * See: https://github.com/angular/angular/issues/11058#issuecomment-247367318
 */
class CustomHttpUrlEncodingCodec extends HttpUrlEncodingCodec {
    /**
     * @param {?} k
     * @return {?}
     */
    encodeKey(k) {
        k = super.encodeKey(k);
        return k.replace(/\+/gi, '%2B');
    }
    /**
     * @param {?} v
     * @return {?}
     */
    encodeValue(v) {
        v = super.encodeValue(v);
        return v.replace(/\+/gi, '%2B');
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const BASE_PATH = new InjectionToken('basePath');
const COLLECTION_FORMATS = {
    'csv': ',',
    'tsv': '   ',
    'ssv': ' ',
    'pipes': '|'
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @record
 */

class Configuration {
    /**
     * @param {?=} configurationParameters
     */
    constructor(configurationParameters = {}) {
        this.apiKeys = configurationParameters.apiKeys;
        this.username = configurationParameters.username;
        this.password = configurationParameters.password;
        this.accessToken = configurationParameters.accessToken;
        this.basePath = configurationParameters.basePath;
        this.withCredentials = configurationParameters.withCredentials;
    }
    /**
     * Select the correct content-type to use for a request.
     * Uses {\@link Configuration#isJsonMime} to determine the correct content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param {?} contentTypes - the array of content types that are available for selection
     * @return {?} the selected content-type or <code>undefined</code> if no selection could be made.
     */
    selectHeaderContentType(contentTypes) {
        if (contentTypes.length == 0) {
            return undefined;
        }
        let /** @type {?} */ type = contentTypes.find(x => this.isJsonMime(x));
        if (type === undefined) {
            return contentTypes[0];
        }
        return type;
    }
    /**
     * Select the correct accept content-type to use for a request.
     * Uses {\@link Configuration#isJsonMime} to determine the correct accept content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param {?} accepts - the array of content types that are available for selection.
     * @return {?} the selected content-type or <code>undefined</code> if no selection could be made.
     */
    selectHeaderAccept(accepts) {
        if (accepts.length == 0) {
            return undefined;
        }
        let /** @type {?} */ type = accepts.find(x => this.isJsonMime(x));
        if (type === undefined) {
            return accepts[0];
        }
        return type;
    }
    /**
     * Check if the given MIME is a JSON MIME.
     * JSON MIME examples:
     *   application/json
     *   application/json; charset=UTF8
     *   APPLICATION/JSON
     *   application/vnd.company+json
     * @param {?} mime - MIME (Multipurpose Internet Mail Extensions)
     * @return {?} True if the given MIME is JSON, false otherwise.
     */
    isJsonMime(mime) {
        const /** @type {?} */ jsonMime = new RegExp('^(application\/json|[^;/ \t]+\/[^;/ \t]+[+]json)[ \t]*(;.*)?$', 'i');
        return mime != null && (jsonMime.test(mime) || mime.toLowerCase() === 'application/json-patch+json');
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * My Title
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * OpenAPI spec version: 1.0.0
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
class PriamosWebAssignmentService {
    /**
     * @param {?} httpClient
     * @param {?} basePath
     * @param {?} configuration
     */
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost:5000';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param {?} consumes string[] mime-types
     * @return {?} true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const /** @type {?} */ form = 'multipart/form-data';
        for (const /** @type {?} */ consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?} appId
     * @param {?} userId
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebAssignmentAddPriamosWebUserApp(appId, userId, observe = 'body', reportProgress = false) {
        if (appId === null || appId === undefined) {
            throw new Error('Required parameter appId was null or undefined when calling priamosWebAssignmentAddPriamosWebUserApp.');
        }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling priamosWebAssignmentAddPriamosWebUserApp.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (appId !== undefined && appId !== null) {
            queryParameters = queryParameters.set('appId', /** @type {?} */ (appId));
        }
        if (userId !== undefined && userId !== null) {
            queryParameters = queryParameters.set('userId', /** @type {?} */ (userId));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.post(`${this.basePath}/api/PriamosWebAssignment/AddPriamosWebUserApp`, null, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} groupId
     * @param {?} userId
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebAssignmentAddPriamosWebUserGroup(groupId, userId, observe = 'body', reportProgress = false) {
        if (groupId === null || groupId === undefined) {
            throw new Error('Required parameter groupId was null or undefined when calling priamosWebAssignmentAddPriamosWebUserGroup.');
        }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling priamosWebAssignmentAddPriamosWebUserGroup.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (groupId !== undefined && groupId !== null) {
            queryParameters = queryParameters.set('groupId', /** @type {?} */ (groupId));
        }
        if (userId !== undefined && userId !== null) {
            queryParameters = queryParameters.set('userId', /** @type {?} */ (userId));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.post(`${this.basePath}/api/PriamosWebAssignment/AddPriamosWebUserGroup`, null, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} subappId
     * @param {?} userId
     * @param {?} position
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebAssignmentAddPriamosWebUserSubapp(subappId, userId, position, observe = 'body', reportProgress = false) {
        if (subappId === null || subappId === undefined) {
            throw new Error('Required parameter subappId was null or undefined when calling priamosWebAssignmentAddPriamosWebUserSubapp.');
        }
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling priamosWebAssignmentAddPriamosWebUserSubapp.');
        }
        if (position === null || position === undefined) {
            throw new Error('Required parameter position was null or undefined when calling priamosWebAssignmentAddPriamosWebUserSubapp.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (subappId !== undefined && subappId !== null) {
            queryParameters = queryParameters.set('subappId', /** @type {?} */ (subappId));
        }
        if (userId !== undefined && userId !== null) {
            queryParameters = queryParameters.set('userId', /** @type {?} */ (userId));
        }
        if (position !== undefined && position !== null) {
            queryParameters = queryParameters.set('position', /** @type {?} */ (position));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.post(`${this.basePath}/api/PriamosWebAssignment/AddPriamosWebUserSubapp`, null, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} userId
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebAssignmentDeletePriamosWebUserAssignments(userId, observe = 'body', reportProgress = false) {
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling priamosWebAssignmentDeletePriamosWebUserAssignments.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (userId !== undefined && userId !== null) {
            queryParameters = queryParameters.set('userId', /** @type {?} */ (userId));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.delete(`${this.basePath}/api/PriamosWebAssignment/DeletePriamosWebUserAssignments`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebAssignmentGetPriamosWebApps(observe = 'body', reportProgress = false) {
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebAssignment/GetPriamosWebApps`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebAssignmentGetPriamosWebGroups(observe = 'body', reportProgress = false) {
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebAssignment/GetPriamosWebGroups`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebAssignmentGetPriamosWebSubapps(observe = 'body', reportProgress = false) {
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebAssignment/GetPriamosWebSubapps`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebAssignmentGetPriamosWebUserroles(observe = 'body', reportProgress = false) {
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebAssignment/GetPriamosWebUserroles`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
}
PriamosWebAssignmentService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
PriamosWebAssignmentService.ctorParameters = () => [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * My Title
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * OpenAPI spec version: 1.0.0
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
class PriamosWebConfigService {
    /**
     * @param {?} httpClient
     * @param {?} basePath
     * @param {?} configuration
     */
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost:5000';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param {?} consumes string[] mime-types
     * @return {?} true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const /** @type {?} */ form = 'multipart/form-data';
        for (const /** @type {?} */ consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebConfigGetPriamosEmailConfig(observe = 'body', reportProgress = false) {
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebConfig/GetPriamosEmailConfig`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} priamosWebEmailConfigDto
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebConfigUpdatePriamosWebEmailConfig(priamosWebEmailConfigDto, observe = 'body', reportProgress = false) {
        if (priamosWebEmailConfigDto === null || priamosWebEmailConfigDto === undefined) {
            throw new Error('Required parameter priamosWebEmailConfigDto was null or undefined when calling priamosWebConfigUpdatePriamosWebEmailConfig.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(`${this.basePath}/api/PriamosWebConfig/UpdatePriamosWebEmailConfig`, priamosWebEmailConfigDto, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
}
PriamosWebConfigService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
PriamosWebConfigService.ctorParameters = () => [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * My Title
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * OpenAPI spec version: 1.0.0
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
class PriamosWebGroupService {
    /**
     * @param {?} httpClient
     * @param {?} basePath
     * @param {?} configuration
     */
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost:5000';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param {?} consumes string[] mime-types
     * @return {?} true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const /** @type {?} */ form = 'multipart/form-data';
        for (const /** @type {?} */ consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?} userid
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebGroupGetPriamosWebGroupByUserId(userid, observe = 'body', reportProgress = false) {
        if (userid === null || userid === undefined) {
            throw new Error('Required parameter userid was null or undefined when calling priamosWebGroupGetPriamosWebGroupByUserId.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (userid !== undefined && userid !== null) {
            queryParameters = queryParameters.set('userid', /** @type {?} */ (userid));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebGroup/GetPriamosWebGroupByUserId`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebGroupGetPriamosWebGroups(observe = 'body', reportProgress = false) {
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebGroup/GetPriamosWebGroups`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
}
PriamosWebGroupService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
PriamosWebGroupService.ctorParameters = () => [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * My Title
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * OpenAPI spec version: 1.0.0
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
class PriamosWebLoginService {
    /**
     * @param {?} httpClient
     * @param {?} basePath
     * @param {?} configuration
     */
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost:5000';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param {?} consumes string[] mime-types
     * @return {?} true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const /** @type {?} */ form = 'multipart/form-data';
        for (const /** @type {?} */ consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebLoginAlive(observe = 'body', reportProgress = false) {
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebLogin/Alive`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} username
     * @param {?} password
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebLoginGetPriamosWebAccessAllowed(username, password, observe = 'body', reportProgress = false) {
        if (username === null || username === undefined) {
            throw new Error('Required parameter username was null or undefined when calling priamosWebLoginGetPriamosWebAccessAllowed.');
        }
        if (password === null || password === undefined) {
            throw new Error('Required parameter password was null or undefined when calling priamosWebLoginGetPriamosWebAccessAllowed.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (username !== undefined && username !== null) {
            queryParameters = queryParameters.set('username', /** @type {?} */ (username));
        }
        if (password !== undefined && password !== null) {
            queryParameters = queryParameters.set('password', /** @type {?} */ (password));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.post(`${this.basePath}/api/PriamosWebLogin/GetPriamosWebAccessAllowed`, null, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} username
     * @param {?} password
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebLoginGetPriamosWebAccessUserDto(username, password, observe = 'body', reportProgress = false) {
        if (username === null || username === undefined) {
            throw new Error('Required parameter username was null or undefined when calling priamosWebLoginGetPriamosWebAccessUserDto.');
        }
        if (password === null || password === undefined) {
            throw new Error('Required parameter password was null or undefined when calling priamosWebLoginGetPriamosWebAccessUserDto.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (username !== undefined && username !== null) {
            queryParameters = queryParameters.set('username', /** @type {?} */ (username));
        }
        if (password !== undefined && password !== null) {
            queryParameters = queryParameters.set('password', /** @type {?} */ (password));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.post(`${this.basePath}/api/PriamosWebLogin/GetPriamosWebAccessUserDto`, null, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} userid
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebLoginGetPriamosWebUserGroups(userid, observe = 'body', reportProgress = false) {
        if (userid === null || userid === undefined) {
            throw new Error('Required parameter userid was null or undefined when calling priamosWebLoginGetPriamosWebUserGroups.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (userid !== undefined && userid !== null) {
            queryParameters = queryParameters.set('userid', /** @type {?} */ (userid));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebLogin/GetPriamosWebUserGroups`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} userId
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebLoginGetPriamosWebUserProfile(userId, observe = 'body', reportProgress = false) {
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling priamosWebLoginGetPriamosWebUserProfile.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (userId !== undefined && userId !== null) {
            queryParameters = queryParameters.set('userId', /** @type {?} */ (userId));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebLogin/GetPriamosWebUserProfile`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} userid
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebLoginGetPriamosWebUserSubapps(userid, observe = 'body', reportProgress = false) {
        if (userid === null || userid === undefined) {
            throw new Error('Required parameter userid was null or undefined when calling priamosWebLoginGetPriamosWebUserSubapps.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (userid !== undefined && userid !== null) {
            queryParameters = queryParameters.set('userid', /** @type {?} */ (userid));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebLogin/GetPriamosWebUserSubapps`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} userid
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebLoginGetPriamosWebUserroleByUserId(userid, observe = 'body', reportProgress = false) {
        if (userid === null || userid === undefined) {
            throw new Error('Required parameter userid was null or undefined when calling priamosWebLoginGetPriamosWebUserroleByUserId.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (userid !== undefined && userid !== null) {
            queryParameters = queryParameters.set('userid', /** @type {?} */ (userid));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebLogin/GetPriamosWebUserroleByUserId`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
}
PriamosWebLoginService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
PriamosWebLoginService.ctorParameters = () => [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * My Title
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * OpenAPI spec version: 1.0.0
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
class PriamosWebMetadataService {
    /**
     * @param {?} httpClient
     * @param {?} basePath
     * @param {?} configuration
     */
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost:5000';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param {?} consumes string[] mime-types
     * @return {?} true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const /** @type {?} */ form = 'multipart/form-data';
        for (const /** @type {?} */ consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebMetadataGetPriamosWebMessages(observe = 'body', reportProgress = false) {
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebMetadata/GetPriamosWebMessages`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
}
PriamosWebMetadataService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
PriamosWebMetadataService.ctorParameters = () => [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * My Title
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * OpenAPI spec version: 1.0.0
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
class PriamosWebUserService {
    /**
     * @param {?} httpClient
     * @param {?} basePath
     * @param {?} configuration
     */
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'http://localhost:5000';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param {?} consumes string[] mime-types
     * @return {?} true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const /** @type {?} */ form = 'multipart/form-data';
        for (const /** @type {?} */ consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebUserAlive(observe = 'body', reportProgress = false) {
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebUser/Alive`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} priamosWebUserDto
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebUserCreatePriamosWebUser(priamosWebUserDto, observe = 'body', reportProgress = false) {
        if (priamosWebUserDto === null || priamosWebUserDto === undefined) {
            throw new Error('Required parameter priamosWebUserDto was null or undefined when calling priamosWebUserCreatePriamosWebUser.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/api/PriamosWebUser/CreatePriamosWebUser`, priamosWebUserDto, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebUserDeletePriamosWebUser(id, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling priamosWebUserDeletePriamosWebUser.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (id !== undefined && id !== null) {
            queryParameters = queryParameters.set('id', /** @type {?} */ (id));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.delete(`${this.basePath}/api/PriamosWebUser/DeletePriamosWebUser`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebUserGetPriamosWebUserById(id, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling priamosWebUserGetPriamosWebUserById.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (id !== undefined && id !== null) {
            queryParameters = queryParameters.set('id', /** @type {?} */ (id));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebUser/GetPriamosWebUserById`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebUserGetPriamosWebUsers(observe = 'body', reportProgress = false) {
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/api/PriamosWebUser/GetPriamosWebUsers`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} priamosWebUserDto
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebUserUpdatePriamosWebUser(priamosWebUserDto, observe = 'body', reportProgress = false) {
        if (priamosWebUserDto === null || priamosWebUserDto === undefined) {
            throw new Error('Required parameter priamosWebUserDto was null or undefined when calling priamosWebUserUpdatePriamosWebUser.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(`${this.basePath}/api/PriamosWebUser/UpdatePriamosWebUser`, priamosWebUserDto, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} userId
     * @param {?} roleId
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    priamosWebUserUpdatePriamosWebUserRole(userId, roleId, observe = 'body', reportProgress = false) {
        if (userId === null || userId === undefined) {
            throw new Error('Required parameter userId was null or undefined when calling priamosWebUserUpdatePriamosWebUserRole.');
        }
        if (roleId === null || roleId === undefined) {
            throw new Error('Required parameter roleId was null or undefined when calling priamosWebUserUpdatePriamosWebUserRole.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (userId !== undefined && userId !== null) {
            queryParameters = queryParameters.set('userId', /** @type {?} */ (userId));
        }
        if (roleId !== undefined && roleId !== null) {
            queryParameters = queryParameters.set('roleId', /** @type {?} */ (roleId));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            'application/json'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.put(`${this.basePath}/api/PriamosWebUser/UpdatePriamosWebUserRole`, null, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
}
PriamosWebUserService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
PriamosWebUserService.ctorParameters = () => [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const APIS = [PriamosWebAssignmentService, PriamosWebConfigService, PriamosWebGroupService, PriamosWebLoginService, PriamosWebMetadataService, PriamosWebUserService];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ApiModule {
    /**
     * @param {?} parentModule
     * @param {?} http
     */
    constructor(parentModule, http) {
        if (parentModule) {
            throw new Error('ApiModule is already loaded. Import in your base AppModule only.');
        }
        if (!http) {
            throw new Error('You need to import the HttpClientModule in your AppModule! \n' +
                'See also https://github.com/angular/angular/issues/20575');
        }
    }
    /**
     * @param {?} configurationFactory
     * @return {?}
     */
    static forRoot(configurationFactory) {
        return {
            ngModule: ApiModule,
            providers: [{ provide: Configuration, useFactory: configurationFactory }]
        };
    }
}
ApiModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: [],
                exports: [],
                providers: [
                    PriamosWebAssignmentService,
                    PriamosWebConfigService,
                    PriamosWebGroupService,
                    PriamosWebLoginService,
                    PriamosWebMetadataService,
                    PriamosWebUserService
                ]
            },] },
];
/** @nocollapse */
ApiModule.ctorParameters = () => [
    { type: ApiModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
    { type: HttpClient, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { APIS, PriamosWebAssignmentService, PriamosWebConfigService, PriamosWebGroupService, PriamosWebLoginService, PriamosWebMetadataService, PriamosWebUserService, BASE_PATH, COLLECTION_FORMATS, Configuration, ApiModule };
//# sourceMappingURL=zeusautomation-priamosweb-angular-api.js.map
